@@ -3,6 +3,9 @@
 # The without snapshot comes from the error in
 # https://github.com/nodejs/node/issues/4212.
 ./configure --prefix=$PREFIX --without-snapshot
-make
+make -j${CPU_COUNT}
 make install
 
+node -v
+npm version
+
